@@ -1,11 +1,10 @@
 package Siebel::Srvrmgr;
+$Siebel::Srvrmgr::VERSION = '0.21';
 use warnings;
 use strict;
-use Log::Log4perl;
+use Log::Log4perl 1.41;
 use Carp;
 
-our $VERSION = "0.20";
-
 =pod
 
 =head1 NAME
