@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Comps_source;
-
+$Siebel::Srvrmgr::Comps_source::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -22,7 +22,7 @@ The hash reference items will be updated and the same reference will be returned
 
 =cut
 
-use Moose::Role;
+use Moose::Role 2.1604;
 use warnings;
 use strict;
 
