@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Action;
-
+$Siebel::Srvrmgr::Daemon::Action::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -50,7 +50,7 @@ infinite loop.
 =cut
 
 use Moose;
-use namespace::autoclean;
+use namespace::autoclean 0.13;
 use Carp;
 
 =pod
