@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Action::CheckComps;
-
+$Siebel::Srvrmgr::Daemon::Action::CheckComps::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -27,9 +27,9 @@ Siebel::Srvrmgr::Daemon::Action::CheckComps - subclass of Siebel::Srvrmgr::Daemo
 
 =cut
 
-use Moose;
-use namespace::autoclean;
-use Moose::Util qw(does_role);
+use Moose 2.0401;
+use namespace::autoclean 0.13;
+use Moose::Util 2.1604 qw(does_role);
 use Siebel::Srvrmgr::Daemon::ActionStash;
 use Siebel::Srvrmgr;
 
