@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Action::LoadPreferences;
-
+$Siebel::Srvrmgr::Daemon::Action::LoadPreferences::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -8,16 +8,14 @@ Siebel::Srvrmgr::Daemon::Action::LoadPreferences - dummy subclass of Siebel::Srv
 
 =head1 SYNOPSIS
 
-	use Siebel::Srvrmgr::Daemon::Action::LoadPreferences;
-
-	my $action = Siebel::Srvrmgr::Daemon::Action::LoadPreferences->new(parser => Siebel::Srvrmgr::ListParser->new());
-
-	$action->do(\@output);
+    use Siebel::Srvrmgr::Daemon::Action::LoadPreferences;
+    my $action = Siebel::Srvrmgr::Daemon::Action::LoadPreferences->new(parser => Siebel::Srvrmgr::ListParser->new());
+    $action->do(\@output);
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 
 extends 'Siebel::Srvrmgr::Daemon::Action';
 
