@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::ActionFactory;
-
+$Siebel::Srvrmgr::Daemon::ActionFactory::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -26,7 +26,7 @@ to define the Action objects to process generated output.
 
 use warnings;
 use strict;
-use MooseX::AbstractFactory;
+use MooseX::AbstractFactory 0.004000;
 
 =pod
 
