@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Condition;
-
+$Siebel::Srvrmgr::Daemon::Condition::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -16,8 +16,8 @@ Siebel::Srvrmgr::Daemon::Condition - object that checks which conditions should
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 
 =pod
 
