@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Heavy;
-
+$Siebel::Srvrmgr::Daemon::Heavy::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -64,8 +64,8 @@ before trying to use it.
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::Daemon::Condition;
 use Siebel::Srvrmgr::Daemon::ActionFactory;
 use Siebel::Srvrmgr::Regexes
