@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Light;
-
+$Siebel::Srvrmgr::Daemon::Light::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -55,19 +55,23 @@ would be a good choice for using with Inetd and Xinetd daemons.
 This class is also highly recommended for OS plataforms like Microsoft Windows where IPC is not reliable enough, since this class uses C<system> instead of
 L<IPC::Open3>.
 
+Since version 0.21, this class does not overrides anymore the parent class method C<shift_command>. Some attention is required is this matter, since a instance of
+Siebel::Srvrmgr::Daemon::Light will not maintain configuration previously loaded with C<load preferences> command. Be sure to maintain this command everytime you invoke
+C<run> available in the C<commands> attribute.
+
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::Daemon::ActionFactory;
 use Siebel::Srvrmgr::ListParser;
 use Siebel::Srvrmgr::Daemon::Command;
 use Config;
 use Carp qw(longmess);
-use File::Temp qw(:POSIX);
+use File::Temp 0.2304 qw(:POSIX);
 use Data::Dumper;
 use Siebel::Srvrmgr;
-use File::BOM qw(:all);
+use File::BOM 0.14 qw(:all);
 use Siebel::Srvrmgr::IPC qw(check_system);
 
 extends 'Siebel::Srvrmgr::Daemon';
@@ -346,35 +350,6 @@ override _setup_commands => sub {
 
 };
 
-=pod
-
-=head2 shift_commands
-
-Overrided from parent class.
-
-If the first command is a LOAD PREFERENCES, the C<commands> attribute will not be shifted and the method returns C<undef>.
-
-Otherwise, the same behaviour from parent will be executed.
-
-=cut
-
-override shift_commands => sub {
-
-    my $self = shift;
-
-    if ( $self->get_commands()->[0]->get_command() =~ /load\spreferences/i ) {
-
-        return undef;
-
-    }
-    else {
-
-        return super();
-
-    }
-
-};
-
 override _define_params => sub {
 
     my $self = shift;
