@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Buffer;
-
+$Siebel::Srvrmgr::ListParser::Buffer::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -8,8 +8,8 @@ Siebel::Srvrmgr::ListParser::Buffer - class to store output of commands
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 
 =pod
 
@@ -95,8 +95,6 @@ sub set_content {
 
         push( @{$buffer_ref}, $value );
 
-        $self->_set_content($buffer_ref);
-
     }
 
 }
@@ -105,11 +103,11 @@ sub set_content {
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 This file is part of Siebel Monitoring Tools.
 
@@ -124,7 +122,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
+along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
