@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::ListServers::Server;
-
+$Siebel::Srvrmgr::ListParser::Output::ListServers::Server::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -8,10 +8,10 @@ Siebel::Srvrmgr::ListParser::Output::ListServers::Server - class that represents
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::Types;
-use MooseX::FollowPBP;
+use MooseX::FollowPBP 0.05;
 
 with 'Siebel::Srvrmgr::ListParser::Output::Duration';
 with 'Siebel::Srvrmgr::ListParser::Output::ToString';
