@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::Set;
-
+$Siebel::Srvrmgr::ListParser::Output::Set::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -8,8 +8,8 @@ Siebel::Srvrmgr::ListParser::Output::Set - subclass to parse set command.
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Carp;
 
 extends 'Siebel::Srvrmgr::ListParser::Output';
