@@ -1,8 +1,8 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ByServer;
-
+$Siebel::Srvrmgr::ListParser::Output::Tabular::ByServer::VERSION = '0.21';
 use strict;
 use warnings;
-use Moose::Role;
+use Moose::Role 2.1604;
 use Siebel::Srvrmgr::Regexes qw(SIEBEL_SERVER);
 
 =head1 NAME
