@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp;
-
+$Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -8,8 +8,8 @@ Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp - subclass that parses li
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Server;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Comp;
 
