@@ -1,7 +1,7 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListCompTypes;
-
-use Moose;
-use namespace::autoclean;
+$Siebel::Srvrmgr::ListParser::Output::Tabular::ListCompTypes::VERSION = '0.21';
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 
 =pod
 
