@@ -1,6 +1,7 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListServers;
-use Moose;
-use namespace::autoclean;
+$Siebel::Srvrmgr::ListParser::Output::Tabular::ListServers::VERSION = '0.21';
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::ListParser::Output::ListServers::Server;
 
 =pod
