@@ -1,7 +1,7 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListSessions;
-
-use Moose;
-use namespace::autoclean;
+$Siebel::Srvrmgr::ListParser::Output::Tabular::ListSessions::VERSION = '0.21';
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Carp qw(cluck);
 use Siebel::Srvrmgr::Regexes qw(SIEBEL_SERVER);
 
