@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::Struct;
-
+$Siebel::Srvrmgr::ListParser::Output::Tabular::Struct::VERSION = '0.21';
 =pod
 
 =head1 NAME
@@ -8,8 +8,8 @@ Siebel::Srvrmgr::ListParser::Output::Tabular::Struct - base class for parsing sr
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Carp;
 
 =pod
