@@ -1,8 +1,8 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::Struct::Delimited;
-
-use Moose;
+$Siebel::Srvrmgr::ListParser::Output::Tabular::Struct::Delimited::VERSION = '0.21';
+use Moose 2.0401;
 use Carp;
-use namespace::autoclean;
+use namespace::autoclean 0.13;
 
 extends 'Siebel::Srvrmgr::ListParser::Output::Tabular::Struct';
 
