@@ -1,6 +1,6 @@
 package Siebel::Srvrmgr::ListParser::Output::ToString;
-
-use Moose::Role;
+$Siebel::Srvrmgr::ListParser::Output::ToString::VERSION = '0.21';
+use Moose::Role 2.1604;
 use Carp;
 use warnings;
 use strict;
